@@ -2,7 +2,7 @@
 // https://github.com/rust-lang/rust/issues/55779
 extern crate serde;
 
-use ruma_events::StateEventContent;
+use ruma_events::{StateEventContent, Unsigned};
 use ruma_events_macros::Event;
 
 /// State event.
@@ -11,6 +11,7 @@ pub struct StateEvent<C: StateEventContent> {
     pub content: C,
     pub state_key: String,
     pub prev_content: Option<C>,
+    pub unsigned: Unsigned,
 }
 
 fn main() {}
